Standar Survey — Euphorie

# Standard Survey

By filling in the list of questions, you have completed a risk assessment. This assessment is used to draw up an action plan. The progress of this action plan must be discussed annually and a small report must be written on the progress. Certain subjects might have been completed and perhaps new subjects need to be added.

Your answers and report were automatically saved and may be found back or deleted at any time via the preparation screen.

Extra remarks for this particular survey.

## Bedrijfsgegevens

Bedrijfsnaam
  Not provided
Postal address
Visitor's address
  Not provided
Email address
  jane.doe@tno.nl
Telephone number
  +316123456789
Activity
  Flubbelen
Name submitter
  Wichert Akkerman
Function submitter
  Tralala
Department
  Development
Location
  Galeries Lafayette Berlin
Submitted on
  Not provided
Email address
  jane.doe@tno.nl
Number of employees
  25 employees or less
Absentee percentage
  12%
Number of accidents last year
  3
Number of incapacitated workers last year
  5
Arbo export
  Jan Doedel

## 1 Workplaces and workshops

### 1.1 Hydraulic ramp

>

#### 1.1.1 We must take care of the following: The hydraulic ramps operate correctly, are inspected and well maintained.

This is a low priority risk

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Aenean lacinia, dui quis sollicitudin blandit, mi massa porta dui, nec venenatis nisl sapien semper dui. Donec vitae tellus faucibus nisi porta dignissim. Phasellus elit ligula, egestas tempus fermentum ac, aliquam sed augue. Phasellus id fermentum odio. In hac habitasse platea dictumst. Nulla nec neque sed lacus convallis ullamcorper. Aliquam erat volutpat. Sed at viverra mauris. Nulla tincidunt consequat mauris, eget porttitor nibh tempor quis. Curabitur vitae lectus in lacus ultricies vehicula. Curabitur non odio eu nunc semper cursus et a elit. Nulla venenatis molestie sem, in volutpat libero facilisis vehicula.

> Aenean lacinia, dui quis sollicitudin blandit, mi massa porta dui, nec venenatis nisl.

### 1.2 Inspection pit

>

#### ⚠ 1.2.1 The inspection pit has only one exit

This is a high priority risk

1. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Aenean lacinia, dui quis sollicitudin blandit, mi massa porta dui, nec venenatis nisl sapien semper dui. Donec vitae tellus faucibus nisi porta dignissim. Phasellus elit ligula, egestas tempus fermentum ac, aliquam sed augue. Phasellus id fermentum odio. In hac habitasse platea dictumst. Nulla nec neque sed lacus convallis ullamcorper. Aliquam erat volutpat. Sed at viverra mauris. Nulla tincidunt consequat mauris, eget porttitor nibh tempor quis.
2. Lorem ipsum
3. Lorem ipsum
4. Lorem ipsum

Nulla nec neque sed lacus convallis ullamcorper. Aliquam erat volutpat. Sed at viverra mauris. Nulla tincidunt consequat mauris, eget porttitor nibh tempor quis. Curabitur vitae lectus in lacus ultricies vehicula. Curabitur non odio eu nunc semper cursus et a elit. Nulla venenatis molestie sem, in volutpat libero facilisis vehicula.

##### Measure 1

Action plan:
  Nulla tincidunt consequat mauris, eget porttitor nibh tempor quis. Curabitur vitae lectus in lacus ultricies vehicula.
Prevention plan:
  Sed at viverra mauris. Nulla tincidunt consequat mauris.
Requirements plan:
  Sed at viverra mauris. Nulla tincidunt consequat mauris.

Barack Obama is responsible for this task which starts on 14 April 2010 and ends on 30 april 2010. There is a budget of € 32.000,- for this measure

#### 1.2.2 The lights are switched on by turning on the ventilation in the inspection pit.

This is a medium priority risk.

Nisi porta dignissim. Phasellus elit ligula, egestas tempus fermentum ac, aliquam sed augue. Phasellus id fermentum odio. In hac habitasse platea dictumst. Nulla nec neque sed lacus convallis ullamcorper. Aliquam erat volutpat. Sed at viverra mauris. Nulla tincidunt consequat mauris, eget porttitor nibh tempor quis. Curabitur vitae lectus in lacus ultricies vehicula. Curabitur non odio eu nunc semper cursus et a elit. Nulla venenatis molestie sem, in volutpat libero facilisis vehicula.

#### 1.2.3 The lighting consists of explosion-safe fittings.

This is a low priority risk

Donec vitae tellus faucibus nisi porta dignissim. Phasellus elit ligula, egestas tempus fermentum ac, aliquam sed augue. Phasellus id fermentum odio. In hac habitasse platea dictumst. Nulla nec neque sed lacus convallis ullamcorper. Aliquam erat volutpat. Sed at viverra mauris. Nulla tincidunt consequat mauris, eget porttitor nibh tempor quis. Curabitur vitae lectus in lacus ultricies vehicula. Curabitur non odio eu nunc semper cursus et a elit. Nulla venenatis molestie sem, in volutpat libero facilisis vehicula.

#### 1.2.4 The ventilation capacity in the inspection pit is sufficient.

This risk still needs to be inventorised

This is a medium priority risk.

Mi massa porta dui, nec venenatis nisl sapien semper dui. Donec vitae tellus faucibus nisi porta dignissim. Phasellus elit ligula, egestas tempus fermentum ac, aliquam sed augue. Phasellus id fermentum odio. In hac habitasse platea dictumst. Nulla nec neque sed lacus convallis ullamcorper. Aliquam erat volutpat. Sed at viverra mauris. Nulla tincidunt consequat mauris, eget porttitor nibh tempor quis. Curabitur vitae lectus in lacus ultricies vehicula. Curabitur non odio eu nunc semper cursus et a elit. Nulla venenatis molestie sem, in volutpat libero facilisis vehicula.

- This report was based on the survey 'Lorem ipsum dolor sit amet' of revision date 12 maart 2009.
- De OR is met dit rapport akkoord gegaan op 16 augustus 2009.

1. Start
2. Analyse
3. Evaluate
4. Action plan
5. Report

Disclaimer | About | Developed by TNO, Syslab and Simplon. Design by Cornae.